@@ -1,4 +1,4 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 
 import copy
 
@@ -9,8 +9,6 @@ import tensorflow as tf
 import uproot
 
 import zfit
-# noinspection PyUnresolvedReferences
-from zfit.core.testing import setup_function, teardown_function, tester
 
 obs1 = ('obs1', 'obs2', 'obs3')
 
@@ -36,7 +34,7 @@ def test_from_root(weights_factory):
     f = uproot.open(path_root)
     tree = f['events']
 
-    true_data = tree.pandas.df()
+    true_data = tree.arrays(library='pd')
 
     data = zfit.Data.from_root(path=path_root, treepath='events', branches=branches, weights=weights)
     x = data.value()
@@ -178,6 +176,7 @@ def test_subdata():
     assert data1.obs == obs1
     np.testing.assert_array_equal(example_data1, data1.value())
 
+
 @pytest.mark.parametrize("weights_factory", [lambda: None,
                                              lambda: np.random.normal(size=5), ])
 def test_data_range(weights_factory):
