@@ -51,10 +51,11 @@ verbosity = None
 def make_min_grad_hesse():
     minimizers = [
         zfit.minimize.ScipyTruncNCV1,
-        zfit.minimize.ScipyTrustNCGV1,
-        zfit.minimize.ScipyTrustKrylovV1,
+        # zfit.minimize.ScipyTrustNCGV1,  # Too bad
+        # zfit.minimize.ScipyTrustKrylovV1,  # Too bad
         zfit.minimize.ScipySLSQPV1,
         zfit.minimize.ScipyLBFGSBV1,
+        zfit.minimize.ScipyTrustConstrV1,
     ]
     min_options = []
     for opt in minimizers:
@@ -75,7 +76,7 @@ def not_allowed(gradient, hessian):
 
 
 @pytest.mark.parametrize('minimizer_gradient_hessian', make_min_grad_hesse())
-@pytest.mark.flaky(reruns=3)
+# @pytest.mark.flaky(reruns=3)
 def test_scipy_derivative_options(minimizer_gradient_hessian):
     minimizer_cls, gradient, hessian = minimizer_gradient_hessian
     loss, true_min, params = create_loss(obs1=obs1)
@@ -125,11 +126,12 @@ minimizers = [
     # SciPy Minimizer
     (zfit.minimize.ScipyLBFGSBV1, {'tol': 1e-5, "verbosity": verbosity}, {'error': True,
                                                                           'numgrad': False, 'approx': True}),
-    (zfit.minimize.ScipyTrustNCGV1, {'tol': 1e-5, "verbosity": verbosity}, True),
-    (zfit.minimize.ScipyTrustKrylovV1, {"verbosity": verbosity}, True),
+    # (zfit.minimize.ScipyTrustNCGV1, {'tol': 1e-5, "verbosity": verbosity}, True),
+    # (zfit.minimize.ScipyTrustKrylovV1, {"verbosity": verbosity}, True),  # Too unstable
     (zfit.minimize.ScipyTrustConstrV1, {"verbosity": verbosity, }, {'error': True, 'longtests': True}),
     (zfit.minimize.ScipyPowellV1, {"verbosity": verbosity, }, {'error': True}),
     (zfit.minimize.ScipySLSQPV1, {"verbosity": verbosity, }, {'error': True}),
+    # (zfit.minimize.ScipyCOBYLAV1, {"verbosity": verbosity, }, {'error': True}),  # Too bad
     # (zfit.minimize.ScipyDoglegV1, {'tol': 1e-5, "verbosity": verbosity}, True),  # works badly
     # (zfit.minimize.ScipyNewtonCGV1, {"verbosity":verbosity,}, {'error': True}),  # Too sensitive? Fails in line-search?
     (zfit.minimize.ScipyTruncNCV1, {"verbosity": verbosity, }, {'error': True}),
@@ -163,7 +165,6 @@ minimizers = [
 # minimizers = [(zfit.minimize.ScipySLSQPV1, {'verbosity': 7}, True)]
 # minimizers = [(zfit.minimize.ScipyNelderMeadV1, {'verbosity': 7}, True)]
 # minimizers = [(zfit.minimize.ScipyCOBYLAV1, {'verbosity': 7}, True)]
-# minimizers = [(zfit.minimize.NLoptCOBYLAV1, {'verbosity': 7}, True)]
 # minimizers = [(zfit.minimize.ScipyNewtonCGV1, {'verbosity': 7}, True)]
 # minimizers = [(zfit.minimize.ScipyTrustNCGV1, {'tol': 1e-3, 'verbosity': 7}, True)]
 # minimizers = [(zfit.minimize.ScipyTruncNCV1, {'tol': 1e-5, 'verbosity': 7}, True)]
@@ -191,7 +192,7 @@ minimizers = sorted(minimizers, key=lambda val: repr(val))
 
 minimizers_small = [
     (zfit.minimize.NLoptLBFGSV1, {}, True),
-    (zfit.minimize.ScipyTrustKrylovV1, {}, True),
+    (zfit.minimize.ScipyTrustConstrV1, {}, True),
     (zfit.minimize.Minuit, {}, True),
     (zfit.minimize.IpyoptV1, {}, False),
 ]
