@@ -1,11 +1,9 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 import numpy as np
 import pytest
 
 import zfit
 from zfit import Parameter
-# noinspection PyUnresolvedReferences
-from zfit.core.testing import setup_function, teardown_function, tester
 from zfit.models.dist_tfp import Gauss
 
 mu1_true = 1.
