@@ -1,7 +1,6 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
+
 
-# noinspection PyUnresolvedReferences
-from zfit.core.testing import setup_function, teardown_function, tester
 # deactivating CUDA capable gpus
 from zfit.z.tools import _auto_upcast
 
@@ -12,11 +11,10 @@ if suppress_gpu:
     os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"  # see issue #152
     os.environ["CUDA_VISIBLE_DEVICES"] = ""
 
+import numpy as np
 import pytest
 import tensorflow as tf
 
-import numpy as np
-
 import zfit.z.math
 
 prec = 0.00001
