@@ -1,7 +1,7 @@
 """Define Parameter which holds the value."""
 #  Copyright (c) 2021 zfit
 import abc
-import collections
+import collections.abc
 import functools
 import warnings
 from collections import OrderedDict
@@ -257,9 +257,6 @@ class ZfitParameterMixin(BaseNumeric):
         return self._name
 
     def __del__(self):
-        with suppress(NotImplementedError):  # PY36 bug, gets stuck
-            if self.name in self._existing_params:  # bug, creates segmentation fault in unittests
-                del self._existing_params[self.name]
         with suppress(AttributeError, NotImplementedError):  # if super does not have a __del__
             super().__del__(self)
 
@@ -415,14 +412,16 @@ class Parameter(ZfitParameterMixin, TFBaseVariable, BaseParameter, ZfitIndepende
         """
         return self._check_at_limit(self.value())
 
-    def _check_at_limit(self, value):
+    def _check_at_limit(self, value, exact=False):
         if not self.has_limits:
             return tf.constant(False)
         # Adding a slight tolerance to make sure we're not tricked by numerics due to floating point comparison
         diff = znp.abs(self.upper - self.lower)  # catch if it is minus inf
-        tol = znp.minimum(diff * 1e-8, 1e-8)  # if one limit is inf we would get inf
-        at_lower = z.unstable.less_equal(value, self.lower + tol)
-        at_upper = z.unstable.greater_equal(value, self.upper - tol)
+        tol = znp.minimum(diff * 1e-5, 1e-3)  # if one limit is inf we would get inf
+        if not exact:
+            tol = - tol
+        at_lower = z.unstable.less_equal(value, self.lower - tol)
+        at_upper = z.unstable.greater_equal(value, self.upper + tol)
         return z.unstable.logical_or(at_lower, at_upper)
 
     def value(self):
@@ -521,7 +520,7 @@ class Parameter(ZfitParameterMixin, TFBaseVariable, BaseParameter, ZfitIndepende
                            f" In order to silence this and clip the value, you can use (with caution,"
                            f" advanced) `Parameter.assign`")
                 if run.executing_eagerly():
-                    if self._check_at_limit(value):
+                    if self._check_at_limit(value, exact=True):
                         raise ValueError(message)
                 else:
                     tf.debugging.assert_greater(tf.cast(value, tf.float64),
@@ -769,7 +768,7 @@ class ComposedParameter(BaseComposedParameter):
         super().__init__(params=params_dict, value_fn=value_fn, name=name, dtype=dtype)
 
     def __repr__(self):
-        if tf.executing_eagerly():  # more explicit: we check for exactly this attribute, nothing inside numpy
+        if tf.executing_eagerly():
             value = f'{self.numpy():.4g}'
         else:
             value = "graph-node"
@@ -818,8 +817,8 @@ class ComplexParameter(ComposedParameter):  # TODO: change to real, imag as inpu
 
         Args:
             name: Name of the parameter.
-            real: Modulus (r) the complex number.
-            imag: Argument (phi) of the complex number.
+            mod: Modulus (r) the complex number.
+            arg: Argument (phi) of the complex number.
         """
         mod = convert_to_parameter(mod, name=name + "_mod", prefer_constant=not floating)
         arg = convert_to_parameter(arg, name=name + "_arg", prefer_constant=not floating)
@@ -895,7 +894,7 @@ def convert_to_parameters(value,
                           step_size=None):
     if prefer_constant is None:
         prefer_constant = True
-    if isinstance(value, collections.Mapping):
+    if isinstance(value, collections.abc.Mapping):
         return convert_to_parameters(**value, prefer_constant=False)
     value = convert_to_container(value)
     is_param_already = [isinstance(val, ZfitIndependentParameter) for val in value]
@@ -981,7 +980,9 @@ def convert_to_parameter(value,
         else:
             complex_params = (Parameter(name + '_REALPART', value=znp.real(value)),
                               Parameter(name + '_IMAGPART', value=znp.imag(value)))
-        value = ComplexParameter(name, value_fn=value, params=complex_params)
+        value = ComplexParameter.from_cartesian(name,
+                                                real=complex_params[0],
+                                                imag=complex_params[1])
 
     else:
         if prefer_constant:
