@@ -1,5 +1,5 @@
-#  Copyright (c) 2020 zfit
-from .core.space import Space, combine_spaces, add_spaces
+#  Copyright (c) 2021 zfit
 from .core.coordinates import Coordinates
+from .core.space import Space, add_spaces, combine_spaces
 
 __all__ = ['Space', 'combine_spaces', 'add_spaces', 'Coordinates']
