@@ -1,8 +1,8 @@
 #  Copyright (c) 2021 zfit
 import math
+import platform
 from typing import Callable, Dict, Optional, Union
 
-import ipyopt
 import numpy as np
 
 from ..core.parameter import assign_values, set_values
@@ -214,6 +214,18 @@ class IpyoptV1(BaseMinimizer):
 
     @minimize_supports(init=True)
     def _minimize(self, loss, params, init):
+        try:
+            import ipyopt
+        except ImportError as error:
+            if platform.system() == 'Darwin':
+                raise ImportError("This requires the ipyopt library (https://gitlab.com/g-braeunlich/ipyopt)"
+                                  " to be installed. As there are no wheels on MacOS available"
+                                  " (https://gitlab.com/g-braeunlich/ipyopt/-/issues/4), this is not in the"
+                                  " requirements for MacOS. Please install ipyopt manually to use this minimizer"
+                                  " or install zfit on a 'Linux' environment.") from error
+            else:
+                raise
+
         if init:
             assign_values(params=params, values=init)
         evaluator = self.create_evaluator()
