@@ -1,4 +1,4 @@
-#  Copyright (c) 2020 zfit
+#  Copyright (c) 2021 zfit
 
 # TODO: improve errors of models. Generate more general error, inherit and use more specific?
 import warnings
@@ -40,6 +40,10 @@ class BasePDFSubclassingError(SubclassingError):
     pass
 
 
+class MinimizerSubclassingError(SubclassingError):
+    pass
+
+
 class IntentionAmbiguousError(Exception):
     pass
 
@@ -178,7 +182,7 @@ class ZfitNotImplementedError(NotImplementedError):
             warnings.warn("Prefer to use a more specific subclass. See in `zfit.exceptions`")
 
 
-class FunctionNotImplementedError(ZfitNotImplementedError):
+class FunctionNotImplemented(ZfitNotImplementedError):
     """Any function, e.g. in a BaseModel, that not implemented and a fallback should be called.
 
     Preferably use more specific exceptions
@@ -186,49 +190,55 @@ class FunctionNotImplementedError(ZfitNotImplementedError):
 
 
 class StandardControlFlow(Exception):
-    """An exception that inherits from this class will be regarded as part of the standard control flow
-    and not as an Error. For example, if a function raises that values are NaN, this is often intercepted
-    on purpose."""
+    """An exception that inherits from this class will be regarded as part of the standard control flow and not as an
+    Error.
+
+    For example, if a function raises that values are NaN, this is often intercepted on purpose.
+    """
 
 
-class SpecificFunctionNotImplementedError(FunctionNotImplementedError):
-    """If a specific function, e.g. by the user is not implemented"""
+class SpecificFunctionNotImplemented(FunctionNotImplemented):
+    """If a specific function, e.g. by the user is not implemented."""
 
 
-class MinimizeNotImplementedError(FunctionNotImplementedError):
+class MinimizeNotImplemented(FunctionNotImplemented):
     """The `minimize` function of a minimizer is not implemented."""
 
 
-class MinimizeStepNotImplementedError(FunctionNotImplementedError):
+class MinimizeStepNotImplemented(FunctionNotImplemented):
     """The `step` function of a minimizer is not implemented."""
 
 
-class AnalyticNotImplementedError(ZfitNotImplementedError):
-    """General exception if an analytic way is not implemented"""
+class AnalyticNotImplemented(ZfitNotImplementedError):
+    """General exception if an analytic way is not implemented."""
 
 
-class AnalyticIntegralNotImplementedError(AnalyticNotImplementedError):
+class AnalyticIntegralNotImplemented(AnalyticNotImplemented):
     """If an analytic integral is not provided."""
     pass
 
 
-class AnalyticSamplingNotImplementedError(AnalyticNotImplementedError):
+class AnalyticSamplingNotImplemented(AnalyticNotImplemented):
     """If analytic sampling from a distribution is not possible."""
     pass
 
 
 # PDF class internal handling errors
-class NormRangeNotImplementedError(Exception):
+class NormRangeNotImplemented(StandardControlFlow):
     """Indicates that a function does not support the normalization range argument `norm_range`."""
     pass
 
 
-class MultipleLimitsNotImplementedError(Exception):
+class MultipleLimitsNotImplemented(StandardControlFlow):
     """Indicates that a function does not support several limits in a :py:class:`~zfit.Space`."""
     pass
 
+class InitNotImplemented(StandardControlFlow):
+    """Indicates that a minimize method does not support a FitResult instead of a loss."""
+    pass
 
-class VectorizedLimitsNotImplementedError(Exception):
+
+class VectorizedLimitsNotImplemented(StandardControlFlow):
     """Indicates that a function does not support vectorized (n_events > 1) limits in a :py:class:`~zfit.Space`."""
     pass
 
@@ -236,7 +246,10 @@ class VectorizedLimitsNotImplementedError(Exception):
 # Developer verbose messages
 
 class WorkInProgressError(Exception):
-    """Only for developing purpose! Does not serve as a 'real' Exception."""
+    """Only for developing purpose!
+
+    Does not serve as a 'real' Exception.
+    """
     pass
 
 
@@ -256,3 +269,7 @@ class BehaviorUnderDiscussion(Exception):
                        "")
         msg = default_msg + str(msg)
         super().__init__(msg, *args)
+
+
+class MaximumIterationReached(StandardControlFlow):
+    pass
